@@ -232,7 +232,8 @@ class ModelResourceMeta(PresstResourceMeta):
                         field_type = list
                     elif isinstance(column.type, postgres.HSTORE):
                         field_type = dict
-                    # TODO postgres.JSON case, backwards compatibility.
+                    elif hasattr(postgres, 'JSON') and isinstance(column.type, postgres.JSON):
+                        field_type = dict
                     else:
                         field_type = column.type.python_type
 
@@ -365,13 +366,14 @@ class ModelResource(six.with_metaclass(ModelResourceMeta, PresstResource)):
     def update_item(cls, id_, dct, partial=False):
         item = cls.get_item_for_id(id_)
 
-        for key, value in six.iteritems(dct):
-            setattr(item, key, value)
-
         session = cls._get_session()
 
         try:
             cls._processors.before_update_item(item, dct, partial, cls)
+
+            for key, value in six.iteritems(dct):
+                setattr(item, key, value)
+
             session.commit()
         except:
             session.rollback()
